@@ -48,4 +48,5 @@ if __name__ == '__main__':
     import sys
     arg_only = sys.argv
     arg_only.remove(arg_only[0])
-    LAVATestDispatcher().dispatch(arg_only)
\ No newline at end of file
+    code = LAVATestDispatcher().dispatch(arg_only)
+    if (code != 0): exit(code)
\ No newline at end of file
