@@ -19,12 +19,12 @@ from lava_test.core.parsers import TestParser
 from lava_test.core.runners import TestRunner
 from lava_test.core.tests import Test
 
-
-RUNSTEPS = ["glmemperf -e shmimage"]
+DEFAULT_OPTIONS = "-e shmimage"
+RUNSTEPS = ["glmemperf $(OPTIONS)"]
 PATTERN = "^(?P<test_case_id>\w+):\W+(?P<measurement>\d+) fps"
 
 inst = TestInstaller(deps=["glmemperf"])
-run = TestRunner(RUNSTEPS)
+run = TestRunner(RUNSTEPS, default_options=DEFAULT_OPTIONS)
 parse = TestParser(PATTERN,
                                       appendall={'units':'fps',
                                                  'result':'pass'})
