@@ -19,19 +19,31 @@ from lava_test.core.parsers import TestParser
 from lava_test.core.runners import TestRunner
 from lava_test.core.tests import Test
 
+DEFAULT_OPTIONS = ""
 
-
-INSTALLSTEPS = ['git clone git://git.linaro.org/people/torez/pm-qa.git',
+INSTALLSTEPS = ['git clone git://git.linaro.org/tools/pm-qa.git',
                 'cd pm-qa && make clean && make all']
-RUNSTEPS = ['cd pm-qa && awk -f testcases.awk  run_template']
-DEPS = ['git-core', 'make', 'alsa-utils', 'pulseaudio-utils', 'lame', 'festival', 'wget']
+RUNSTEPS = ['cd pm-qa && make check $(OPTIONS)']
+DEPS = ['git-core', 'make', 'linux-libc-dev', 'util-linux']
 
 pwrmgmtinst = TestInstaller(INSTALLSTEPS, deps=DEPS)
-pwrmgmtrun = TestRunner(RUNSTEPS)
+pwrmgmtrun = TestRunner(RUNSTEPS, default_options=DEFAULT_OPTIONS)
 
-# test case name is between "pm-qa-"  and  ":"  and results and/or
-# measurements are rest of the line
-PATTERN = "^pm-qa-(?P<test_case_id>\w+):\s+(?P<message>.*)"
+# test case name is before  ":" , the test log is between ":" and "...",
+# the result is after "..."
+# Each test case is separated with a test description beginning with "#"
+
+# Example:
+####
+#### cpufreq_02:
+#### test the cpufreq framework is available for governor
+####
+#cpufreq_02.0/cpu0: checking scaling_available_governors exists...        pass
+#cpufreq_02.1/cpu0: checking scaling_governor exists...                   pass
+#cpufreq_02.0/cpu1: checking scaling_available_governors exists...        pass
+#cpufreq_02.1/cpu1: checking scaling_governor exists...                   pass
+
+PATTERN = "^(?P<test_case_id>[\w/\.]+):\s+(?P<message>.+)\.\.\.\s+(?P<result>\w+)"
 
 
 pwrmgmtparser = TestParser(PATTERN,
