@@ -19,12 +19,13 @@ from lava_test.core.runners import TestRunner
 from lava_test.core.tests import Test
 
 INSTALLSTEPS = ['bzr branch lp:~linaro-foundations/lava-test/xrestopscript']
-RUNSTEPS = ["./xrestopscript/xrestop.sh"]
+RUNSTEPS = ["./xrestopscript/xrestop.sh $(OPTIONS)"]
 PATTERN = "^(?P<test_case_id>\w+):\W+(?P<measurement>\d+)"
+DEFAULT_OPTIONS = ""
 
 xrestopinst = TestInstaller(INSTALLSTEPS, deps=["xrestop"])
-xrestoprun = TestRunner(RUNSTEPS)
+xrestoprun = TestRunner(RUNSTEPS,default_options=DEFAULT_OPTIONS)
 xrestopparser = TestParser(PATTERN,
                    appendall={'units':'KB', 'result':'pass'})
-testobj = Test(testname="xrestop", installer=xrestopinst,
+testobj = Test(test_id="xrestop", installer=xrestopinst,
                                   runner=xrestoprun, parser=xrestopparser)
